@@ -21,7 +21,7 @@ from testgear_python_commons.dynamic_methods import (
     message
 )
 from testgear_python_commons.models import LinkType
-from testgear_python_commons.step import Step as step  # noqa: N813
+from testgear_python_commons.step import step
 
 __all__ = [
     'externalID',
